@@ -51,10 +51,19 @@ import logging
 # (https://docs.python.org/3.7/library/os.html#module-os)
 from os import path
 
-# Module "pymysql": Python MySQL client library
-# (https://pypi.org/project/PyMySQL)
-# Using "pymysql" instead of MySQLdb which is limited to python2.7
-from pymysql import connect
+# Module "socket": Low-level networking interface
+# (https://docs.python.org/3.7/library/socket.html#module-socket)
+from socket import gethostname
+
+if str(gethostname()) == "mh3" or str(gethostname()) == "M-iMac142":
+    # Module "pymysql": Python MySQL client library
+    # (https://pypi.org/project/PyMySQL)
+    # Using "pymysql" instead of MySQLdb which is limited to python2.7
+    from pymysql import connect
+elif str(gethostname()) == "mh6":
+    # Module "mariadb": Python MySQL client library
+    # (https://pypi.org/project/mariadb/)
+    from mariadb import connect
 
 # Module "subprocess": Subprocess management
 # (https://docs.python.org/3.7/library/subprocess.html#module-subprocess)
